Skip site navigation (1)Skip section navigation (2)
Date:      Wed, 5 Jan 2011 12:20:55 +0000 (UTC)
From:      Marius Strobl <marius@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-all@freebsd.org, svn-src-stable@freebsd.org, svn-src-stable-7@freebsd.org
Subject:   svn commit: r216999 - stable/7/sys/sparc64/include
Message-ID:  <201101051220.p05CKtqs077790@svn.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: marius
Date: Wed Jan  5 12:20:55 2011
New Revision: 216999
URL: http://svn.freebsd.org/changeset/base/216999

Log:
  MFC: r216801
  
  Rename the "xor" parameter to "xorval" as the former is a reserved keyword
  in C++.
  
  Submitted by:	gahr

Modified:
  stable/7/sys/sparc64/include/cpufunc.h
Directory Properties:
  stable/7/sys/   (props changed)
  stable/7/sys/cddl/contrib/opensolaris/   (props changed)
  stable/7/sys/contrib/dev/acpica/   (props changed)
  stable/7/sys/contrib/pf/   (props changed)

Modified: stable/7/sys/sparc64/include/cpufunc.h
==============================================================================
--- stable/7/sys/sparc64/include/cpufunc.h	Wed Jan  5 12:20:53 2011	(r216998)
+++ stable/7/sys/sparc64/include/cpufunc.h	Wed Jan  5 12:20:55 2011	(r216999)
@@ -157,9 +157,9 @@ int fasword32(u_long asi, void *addr, ui
 	__sr;								\
 })
 
-#define	wr(name, val, xor) do {						\
+#define	wr(name, val, xorval) do {					\
 	__asm __volatile("wr %0, %1, %%" #name				\
-	    : : "r" (val), "rI" (xor));					\
+	    : : "r" (val), "rI" (xorval));				\
 } while (0)
 
 #define	rdpr(name) ({							\
@@ -168,24 +168,24 @@ int fasword32(u_long asi, void *addr, ui
 	__pr;								\
 })
 
-#define	wrpr(name, val, xor) do {					\
+#define	wrpr(name, val, xorval) do {					\
 	__asm __volatile("wrpr %0, %1, %%" #name			\
-	    : : "r" (val), "rI" (xor));					\
+	    : : "r" (val), "rI" (xorval));				\
 } while (0)
 
 /*
  * Trick GAS/GCC into compiling access to TICK/(S)TICK_COMPARE independently
  * of the selected instruction set.
  */
-#define	rdtickcmpr()		rd(asr23)
-#define	rdstick()		rd(asr24)
-#define	rdstickcmpr()		rd(asr25)
-#define	wrtickcmpr(val, xor)	wr(asr23, (val), (xor))
-#define	wrstick(val, xor)	wr(asr24, (val), (xor))
-#define	wrstickcmpr(val, xor)	wr(asr25, (val), (xor))
+#define	rdtickcmpr()			rd(asr23)
+#define	rdstick()			rd(asr24)
+#define	rdstickcmpr()			rd(asr25)
+#define	wrtickcmpr(val, xorval)		wr(asr23, (val), (xorval))
+#define	wrstick(val, xorval)		wr(asr24, (val), (xorval))
+#define	wrstickcmpr(val, xorval)	wr(asr25, (val), (xorval))
 
 /*
  * Macro intended to be used instead of wr(asr23, val, xor) for writing to
  * the TICK_COMPARE register in order to avoid a bug in BlackBird CPUs that
  * can cause these writes to fail under certain condidtions which in turn
  * causes the hardclock to stop.  The workaround is to read the TICK_COMPARE
@@ -193,14 +193,14 @@ int fasword32(u_long asi, void *addr, ui
  * aligned to a quadword boundary in order to ensure that I$ misses won't
  * split them up.
  */
-#define	wrtickcmpr_bbwar(val, xor) ({					\
+#define	wrtickcmpr_bbwar(val, xorval) ({				\
 	__asm __volatile(						\
 	"	ba,pt	%%xcc, 1f ;		"			\
 	"	 nop	 ;			"			\
 	"	.align	128 ;			"			\
 	"1:	wr	%0, %1, %%asr23 ;	"			\
 	"	rd	%%asr23, %%g0 ;		"			\
-	: : "r" (val), "rI" (xor));					\
+	: : "r" (val), "rI" (xorval));					\
 })
 
 static __inline void
@@ -168,24 +168,24 @@ int fasword32(u_long asi, void *addr, ui
 
 /*
- * Macro intended to be used instead of wr(asr23, val, xor) for writing to
+ * Macro intended to be used instead of wr(asr23, val, xorval) for writing to
  * the TICK_COMPARE register in order to avoid a bug in BlackBird CPUs that
  * can cause these writes to fail under certain condidtions which in turn



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201101051220.p05CKtqs077790>